/*
 * Test.java - Simple lpexlet (LPEX external command written in Java) to test
 * LPEX JPI - the LPEX Java Programming Interface.
 *
 * (C) Copyright IBM Corporation 1998
 *
 * DISCLAIMER OF WARRANTIES:
 *
 *   The following enclosed code is sample code created by IBM
 *   Corporation.  This sample code is not part of any standard IBM
 *   product and is provided to you solely for the purpose of assisting
 *   you in the development of your applications.  The code is provided
 *   "AS IS", without warranty of any kind.  IBM shall not be liable
 *   for any damages arising out of your use of the sample code, even
 *   if they have been advised of the possibility of such damages.
 *
 * Notes:
 *   1.- compile it with:
 *         javac Test.java
 *   2.- ensure that the resulting Test.class is in the CLASSPATH
 *   3.- start the editor:
 *         iedit
 *   4.- invoke lpexlet Test from the LPEX command line:
 *         java Test
 */

/******************************************************************************/
/* The lpexlet is Test.  It subclasses LpexCommand, the LPEX JPI.             */
/******************************************************************************/
public class Test extends LpexCommand
{
   // number of calls so far
   static int calls = 0;

   /*=========================================================================*/
   /*  lpexEntry() - main entry point from LPEX.  Overrides LpexCommand's.    */
   /*=========================================================================*/
   public static int lpexEntry (String arg)
   {
      // announce lpexEntry() was called
      if (arg.length() == 0)
         arg = "<none>";
      lpexCall("MSG", "**Test - lpexEntry(), arguments=" + arg);

      // say from which document
      lpexMessage("Call no." + ++calls + ", " +
                  "from document " + lpexDocName());

      // 1st time around, display some environmental info
      if (calls == 1) {
         lpexMessage("Test.class - lpexlet to test the LPEX JPI");
         lpexMessage("LPEX version: " + lpexGetParm("VERSION"));
         lpexMessage("LPEX profile: " + lpexProfile());
         }

      // put up LPEX's LINEREAD dialog, say what happened
      lpexCommand("SET LINEREAD.TITLE Test lpexlet - READLINE dialog");
      lpexCommand("SET LINEREAD.PROMPT Please enter some text below:");
      lpexCommand("LINEREAD 255");
      if (lpexGetParm("LASTKEY").equals("ENTER")) {
         String parm = lpexGetParm("LASTLINE");
         if (parm.length() == 0)
            lpexMessage("No text was entered in the entry field");
         else
            lpexMessage("Text read in: " + parm);
         }
      else
         lpexMessage("You pressed \"Cancel\" on the dialog");

      // clear messageline, [open and] go to the macro log so user sees all this
      lpexCommand("MULT ;MSG ;LP_MACROLOG");

      // return a good return code to LPEX
      return 0;
   }

   /*=========================================================================*/
   /*  lpexNotify() - tell LPEX what to notify us.  Overrides LpexCommand's.  */
   /*=========================================================================*/
   public static int lpexNotify ()
   {
      lpexCall("MSG", "**Test - lpexNotify():  we want ALL notifications...");
      return LPEX_NOTIFY_DOCEXIT + LPEX_NOTIFY_EXIT;
   }

   /*=========================================================================*/
   /*  lpexDocExit() - an LPEX doc being exited.  Overrides LpexCommand's.    */
   /*=========================================================================*/
   public static int lpexDocExit (int docnum)
   {
      lpexCall("MSG", "**Test - lpexDocExit(), for doc no." + docnum);
      return 0;
   }

   /*=========================================================================*/
   /*  lpexExit() - we're being terminated.  Overrides LpexCommand's.         */
   /*=========================================================================*/
   public static int lpexExit (String arg)
   {
      lpexCall("MSG", "**Test - lpexExit(), argument=" + arg);
      return 0;
   }

   /*=========================================================================*/
   /*  lpexMessage() - display an indented message.                           */
   /*=========================================================================*/
   static int        lpexMessage (String s)
   {
      return lpexCommand("MSG   " + s + ".");
   }

   /*=========================================================================*/
   /*  lpexDocName() - get name of calling document, if any.                  */
   /*=========================================================================*/
   static String     lpexDocName ()
   {
      String name = lpexGetParm("NAME");
      if (name.length() == 0) {
         int n = lpexGetIntParm("DOCNUM");
         if (n == 0)
            name = "<none current>";    // probably an "iedit /c java Test" call
         else
            name = "Untitled " + n;
         }
      return name;
   }
}
