/**
 * Toolbar.java - Lpexlet that puts a floating toolbar for LPEX things
 *
 * Notes:
 *   1.- compile it with:
 *         javac Toolbar.java
 *   2.- ensure that the resulting Toolbar.class is in the CLASSPATH
 *   3.- ensure that ToolbarFrame.class is in the CLASSPATH
 *   4.- start the editor:
 *         codeedit
 *   5.- invoke lpexlet Toolbar from the LPEX command line
 *         java Toolbar
 *   Note: this requires the ToolbarFrame class
 */

import ToolbarFrame;

/******************************************************************************/
/* The lpexlet is Toolbar.  It subclasses LpexCommand, the LPEX JPI.          */
/******************************************************************************/
public class Toolbar extends LpexCommand
{
   static ToolbarFrame tframe;

   /*=========================================================================*/
   /*  lpexEntry() - main entry point from LPEX.  Overrides LpexCommand's.    */
   /*=========================================================================*/
   public static int lpexEntry (String arg)
   {

      if (arg.length() != 0) {
         // arguments specified, do something special (eventually),
         // like toolbar orientation / position / buttons / etc.
         }

      if (tframe == null)            // none yet: put up the LPEX remote control
         tframe = new ToolbarFrame();
      else {              // one floating toolbar at any given time is plenty...
         tframe.show();
         tframe.toFront();
         }

      return 0;                             // return a good return code to LPEX
   }

   /*=========================================================================*/
   /*  lpexNotify() - tell LPEX what to notify us.  Overrides LpexCommand's.  */
   /*=========================================================================*/
   public static int lpexNotify ()
   {
      return LPEX_NOTIFY_EXIT;
   }

   /*=========================================================================*/
   /*  lpexExit() - we're being terminated.  Overrides LpexCommand's.         */
   /*=========================================================================*/
   public static int lpexExit (String arg)
   {
      tframe.dispose();                                // get rid of the toolbar
      // tframe = null;
      return 0;
   }

   /*=========================================================================*/
   /*  doSave() - save the file                                               */
   /*=========================================================================*/
   public static int doSave ()
   {
      // save, return to the document (GODOC .)
      int n = lpexGetIntParm("DOCNUM");
      if (n != 0)                  // there is indeed at least one document open
         lpexCommand("MULT ,LP_SAVE,GODOC DOCNUM " + n + ",SSHOW");
      return 0;
   }

   /*=========================================================================*/
   /*  doSaveAs() - save document (into file with a new name)                 */
   /*=========================================================================*/
   public static int doSaveAs ()
   {
      // save as, ensure '*' after document name on title bar gone
      lpexCommand("MULT ,LP_SAVEAS,SSHOW");
      return 0;
   }

   /*=========================================================================*/
   /*  doOpen() - open file(s) for editing                                    */
   /*=========================================================================*/
   public static int doOpen ()
   {
      // open, ensure in doc when previously opened & we now just GODOCed to it
      lpexCommand("MULT ,LP_OPENEDIT,SSHOW");
      return 0;
   }

   /*=========================================================================*/
   /*  doNew() - open a new file                                              */
   /*=========================================================================*/
   public static int doNew ()
   {
      lpexCommand("LP_NEW");
      return 0;
   }

   /*=========================================================================*/
   /*  doGet() - get a file into the current document                         */
   /*=========================================================================*/
   public static int doGet ()
   {
      // get, end undo unit to show +1 change & trigger new text parse, refresh
      lpexCommand("MULT ,LP_GET,CHECK,SSHOW");
      return 0;
   }

   /*=========================================================================*/
   /*  doFind() - find and replace                                            */
   /*=========================================================================*/
   public static int doFind ()
   {
      // go to doc 1st, so "Find" dialog is all under LPEX control in one thread
      int n = lpexGetIntParm("DOCNUM");
      if (n != 0)                  // there is indeed at least one document open
         lpexCommand("MULT ,GODOC DOCNUM " + n + ",SSHOW,LP_FINDCHANGE");
      return 0;
   }
}
